package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.dto.ModelHospitalAllDTO;
import com.diagbot.entity.MedicalRecord;
import com.diagbot.entity.ModelHospital;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.ModelHospitalService;
import com.diagbot.service.impl.ModelHospitalServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.DateUtil;
import com.diagbot.vo.ModelHospitalAllVO;
import com.diagbot.vo.ModelHospitalUpdataVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * @author wangfeng
 * @Description:
 * @date 2020-05-15 14:42
 */
@Component
public class ModelHospitalFacade extends ModelHospitalServiceImpl {

    @Autowired
    ModelHospitalService modelHospitalService;
    @Autowired
    MedicalRecordFacade medicalRecordFacade;

    /**
     *
     * @param modelHospitalAllVO
     * @return
     */
    public IPage<List<ModelHospitalAllDTO>> getModelHospitalAlls(ModelHospitalAllVO modelHospitalAllVO) {
        IPage<List<ModelHospitalAllDTO>> data =  modelHospitalService.getModelHospitalAll(modelHospitalAllVO);
        return data;
    }

    /**
     *
     * @param modeId
     * @return
     */
    public ModelHospitalAllDTO getModelHospitalById(Long modeId) {
        QueryWrapper<ModelHospital> queryModelHospital = new QueryWrapper<>();
        queryModelHospital.eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("id",modeId);
        ModelHospital modelHospital = modelHospitalService.getOne(queryModelHospital);
        if(modelHospital == null){
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "该数据不存在！");
        }
        ModelHospitalAllDTO modelHospitalData =  new ModelHospitalAllDTO();
        BeanUtil.copyProperties(modelHospital,modelHospitalData);
        return  modelHospitalData;
    }

    public Boolean updataModelHospitals(ModelHospitalUpdataVO modelHospitalUpdataVO) {
        QueryWrapper<ModelHospital> queryModelHospital = new QueryWrapper<>();
        queryModelHospital.eq("is_deleted", IsDeleteEnum.N.getKey())
                .ne("id",modelHospitalUpdataVO.getId()==null? -1:modelHospitalUpdataVO.getId())
                .eq("hospital_model_name",modelHospitalUpdataVO.getHospitalModelName());
        int sum = modelHospitalService.count(queryModelHospital);
        if(sum != 0){
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "该名称已存在");
        }
        boolean res= false;
        QueryWrapper<ModelHospital> modelHospitalQuery = new QueryWrapper<>();
        modelHospitalQuery.eq("id",modelHospitalUpdataVO.getId())
                .eq("is_deleted", IsDeleteEnum.N.getKey());
        ModelHospital data = modelHospitalService.getOne(modelHospitalQuery);
        Date date = DateUtil.now();
        if(data!=null){
            ModelHospital modelHospitals  = new ModelHospital();
            BeanUtil.copyProperties(modelHospitalUpdataVO,modelHospitals);
            modelHospitals.setGmtModified(date);
            res = modelHospitalService.updateById(modelHospitals);
            if(res) {
                UpdateWrapper<MedicalRecord> medicalRecordData = new UpdateWrapper<>();
                medicalRecordData.eq("rec_title", modelHospitalUpdataVO.getHospitalModelName())
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", modelHospitalUpdataVO.getHospitalId())
                        .set("mode_id", modelHospitals.getId())
                        .set("gmt_create",date);
                medicalRecordFacade.update(medicalRecordData);
            }
        }else {
            ModelHospital modelHospitalDatas = new ModelHospital();
            BeanUtil.copyProperties(modelHospitalUpdataVO,modelHospitalDatas);
            modelHospitalDatas.setGmtCreate(date);
            modelHospitalDatas.setGmtModified(date);
            res= modelHospitalService.save(modelHospitalDatas);
            if(res) {
                UpdateWrapper<MedicalRecord> medicalRecordData = new UpdateWrapper<>();
                medicalRecordData.eq("rec_title", modelHospitalUpdataVO.getHospitalModelName())
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", modelHospitalUpdataVO.getHospitalId())
                        .set("mode_id", modelHospitalDatas.getId())
                        .set("gmt_create",date);
                medicalRecordFacade.update(medicalRecordData);
            }
        }

        return res;
    }

    public Boolean clearModelHospital(Long modeId) {
        boolean res= false;
        Date date = DateUtil.now();
        UpdateWrapper<ModelHospital> modelHospitalData = new UpdateWrapper<>();
        modelHospitalData.eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("id", modeId)
                .set("is_deleted", IsDeleteEnum.Y.getKey())
                .set("gmt_create",date);
        res = modelHospitalService.update(modelHospitalData);
        UpdateWrapper<MedicalRecord> medicalRecordData = new UpdateWrapper<>();
        medicalRecordData.eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("mode_id", modeId)
                .set("mode_id", 0)
                .set("gmt_create",date);
        medicalRecordFacade.update(medicalRecordData);
        return  res ;
    }
}
