package com.diagbot.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.diagbot.dto.BehospitalInfoDTO;
import com.diagbot.dto.DeptNumDTO;
import com.diagbot.dto.LevelStatisticsDTO;
import com.diagbot.dto.MsgDTO;
import com.diagbot.dto.NumDTO;
import com.diagbot.entity.BehospitalInfo;
import com.diagbot.mapper.BehospitalInfoMapper;
import com.diagbot.service.BehospitalInfoService;
import com.diagbot.vo.AnalyzeCodeVO;
import com.diagbot.vo.AnalyzeVO;
import com.diagbot.vo.BehospitalPageVO;
import com.diagbot.vo.FilterOrderByDeptVO;
import com.diagbot.vo.FilterOrderVO;
import com.diagbot.vo.FilterPageByDeptVO;
import com.diagbot.vo.FilterPageVO;
import com.diagbot.vo.FilterVO;
import com.diagbot.vo.HomePageFilterVO;
import org.apache.ibatis.annotations.Param;
import com.diagbot.vo.TaskVO;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 住院病历信息 服务实现类
 * </p>
 *
 * @author zhoutg
 * @since 2020-04-13
 */
@Service
public class BehospitalInfoServiceImpl extends ServiceImpl<BehospitalInfoMapper, BehospitalInfo> implements BehospitalInfoService {

    @Override
    public IPage<BehospitalInfoDTO> getPage(BehospitalPageVO behospitalPageVO) {
        return baseMapper.getPage(behospitalPageVO);
    }

    @Override
    public List<MsgDTO> getMsg(AnalyzeVO analyzeVO) {
        return baseMapper.getMsg(analyzeVO);
    }

    @Override
    public List<MsgDTO> getMsgByEntryCode(AnalyzeCodeVO analyzeCodeVO) {
        return baseMapper.getMsgByEntryCode(analyzeCodeVO);
    }

    /**
     * 缺陷排行列表统计
     *
     * @param filterVO
     * @return
     */
    @Override
    public List<NumDTO> resultStatistics(FilterVO filterVO) {
        return baseMapper.resultStatistics(filterVO);
    }

    /**
     * 各科室缺陷占比
     *
     * @param filterVO
     * @return
     */
    @Override
    public List<NumDTO> resultStatisticsByDept(FilterVO filterVO) {
        return baseMapper.resultStatisticsByDept(filterVO);
    }

    /**
     * 缺陷排行列表统计-百分比未计算
     *
     * @param filterVO
     * @return
     */
    @Override
    public List<NumDTO> resultStatistics2(FilterVO filterVO) {
        return baseMapper.resultStatistics2(filterVO);
    }

    /**
     * 各科室缺陷占比-百分比未计算
     *
     * @param filterVO
     * @return
     */
    @Override
    public List<NumDTO> resultStatisticsByDept2(FilterVO filterVO) {
        return baseMapper.resultStatisticsByDept2(filterVO);
    }

    /**
     * 缺陷总数
     *
     * @param filterVO
     * @return
     */
    @Override
    public int getTotleResultNum(FilterVO filterVO) {
        return baseMapper.getTotleResultNum(filterVO);
    }

    @Override
    public List<BehospitalInfo> getNoGrade(TaskVO taskVO) {
        return baseMapper.getNoGrade(taskVO);
    }

    @Override
    public IPage<BehospitalInfoDTO> getPageByDept(BehospitalPageVO behospitalPageVO) {
        return baseMapper.getPageByDept(behospitalPageVO);
    }

    @Override
    public IPage<BehospitalInfoDTO> getPageByPerson(BehospitalPageVO behospitalPageVO) {
        return baseMapper.getPageByPerson(behospitalPageVO);
    }

    /**
     * 病案首页相关病历数统计
     *
     * @param homePageFilterVO
     * @return
     */
    @Override
    public int homePageCount(HomePageFilterVO homePageFilterVO) {
        return baseMapper.homePageCount(homePageFilterVO);
    }

    /**
     * 手术病历数统计
     *
     * @param filterVO
     * @return
     */
    @Override
    public int homePageCountForOperation(FilterVO filterVO) {
        return baseMapper.homePageCountForOperation(filterVO);
    }

    /**
     * 按科室统计病案首页病历数
     *
     * @param homePageFilterVO
     * @return
     */
    @Override
    public List<NumDTO> homePageCountByDept(HomePageFilterVO homePageFilterVO) {
        return baseMapper.homePageCountByDept(homePageFilterVO);
    }

    /**
     * 按科室统计病案首页手术病历数
     *
     * @param filterVO
     * @return
     */
    @Override
    public List<NumDTO> homePageCountForOperationByDept(FilterVO filterVO) {
        return baseMapper.homePageCountForOperationByDept(filterVO);
    }

    /**
     * 各科室缺陷占比排行（分页）
     *
     * @param filterPageVO
     * @return
     */
    @Override
    public IPage<NumDTO> resultStatisticsByDeptPage(@Param("filterPageVO") FilterPageVO filterPageVO) {
        return baseMapper.resultStatisticsByDeptPage(filterPageVO);
    }

    /**
     * 各科室缺陷占比（组合）
     *
     * @param filterOrderVO
     * @return
     */
    @Override
    public List<LevelStatisticsDTO> levelStatistics(FilterOrderVO filterOrderVO) {
        return baseMapper.levelStatistics(filterOrderVO);
    }

    /**
     * 病案首页合格率占比
     *
     * @param filterOrderVO
     * @return
     */
    @Override
    public List<LevelStatisticsDTO> homePageLevelStatistics(FilterOrderVO filterOrderVO) {
        return baseMapper.homePageLevelStatistics(filterOrderVO);
    }

    /**
     * 各科室缺陷占比（主任医生）
     *
     * @param filterOrderByDeptVO
     * @return
     */
    @Override
    public List<LevelStatisticsDTO> levelStatisticsByDept(FilterOrderByDeptVO filterOrderByDeptVO) {
        return baseMapper.levelStatisticsByDept(filterOrderByDeptVO);
    }

    /**
     * 病案首页合格率占比（主任医生）
     *
     * @param filterOrderByDeptVO
     * @return
     */
    @Override
    public List<LevelStatisticsDTO> homePageLevelStatisticsByDept(FilterOrderByDeptVO filterOrderByDeptVO) {
        return baseMapper.homePageLevelStatisticsByDept(filterOrderByDeptVO);
    }

    /**
     * 缺陷明细-科室（分页）
     *
     * @param filterPageByDeptVO
     * @return
     */
    public IPage<DeptNumDTO> resultStatisticsByDeptAndDoctorPage(@Param("filterPageByDeptVO") FilterPageByDeptVO filterPageByDeptVO) {
        return baseMapper.resultStatisticsByDeptAndDoctorPage(filterPageByDeptVO);
    }
}