package com.diagbot.web;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.AverageStatisticsDTO;
import com.diagbot.dto.LevelStatisticsDTO;
import com.diagbot.dto.NumDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.facade.ConsoleFacade;
import com.diagbot.vo.FilterOrderVO;
import com.diagbot.vo.FilterPageVO;
import com.diagbot.vo.FilterVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import springfox.documentation.annotations.ApiIgnore;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2020/4/13 16:45
 */
@RequestMapping("/console")
@RestController
@Api(value = "控制台统计相关API", tags = { "控制台统计相关API" })
@SuppressWarnings("unchecked")
public class ConsoleController {

    @Autowired
    private ConsoleFacade consoleFacade;

    //region-----------------------聚合接口开始-------------------------------
    @ApiOperation(value = "病历相关统计[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/mrStatistics")
    @SysLogger("mrStatistics")
    @ApiIgnore
    public RespDTO<Map<String, Object>> mrStatistics(@RequestBody FilterVO filterVO) {
        Map<String, Object> data = consoleFacade.mrStatistics(filterVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "缺陷相关统计[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/resultStatistics")
    @SysLogger("resultStatistics")
    @ApiIgnore
    public RespDTO<Map<String, Object>> resultStatistics(@RequestBody FilterVO filterVO) {
        Map<String, Object> data = consoleFacade.resultStatistics(filterVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "平均值相关统计[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/averageStatistics")
    @SysLogger("averageStatistics")
    @ApiIgnore
    public RespDTO<Map<String, Object>> averageStatistics(@RequestBody FilterVO filterVO) {
        Map<String, Object> data = consoleFacade.averageStatistics(filterVO);
        return RespDTO.onSuc(data);
    }
    //endregion-----------------------聚合接口结束-------------------------------

    //region-----------------------单独接口开始-------------------------------

    /**
     * 平均住院天数
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "平均住院天数[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/getAverageDayNum")
    @SysLogger("getAverageDayNum")
    public RespDTO<Map<String, Object>> getAverageDayNum(@RequestBody FilterVO filterVO) {
        return RespDTO.onSuc(consoleFacade.getAverageDayNum(filterVO));
    }

    /**
     * 平均住院费用
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "平均住院费用[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/getAverageFee")
    @SysLogger("getAverageFee")
    public RespDTO<Map<String, Object>> getAverageFee(@RequestBody FilterVO filterVO) {
        return RespDTO.onSuc(consoleFacade.getAverageFee(filterVO));
    }

    /**
     * 质控平均分按科室统计
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "质控平均分按科室统计[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/getAverageScore")
    @SysLogger("getAverageScore")
    public RespDTO<Map<String, Object>> getAverageScore(@RequestBody FilterVO filterVO) {
        return RespDTO.onSuc(consoleFacade.getAverageScore(filterVO));
    }

    /**
     * 各科室甲级病历占比
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "各科室甲级病历占比[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/getLevelResultDept")
    @SysLogger("getLevelResultDept")
    public RespDTO<Map<String, Object>> getLevelResultDept(@RequestBody FilterVO filterVO) {
        return RespDTO.onSuc(consoleFacade.getLevelResultDept(filterVO));
    }

    /**
     * 出院人数统计
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "出院人数统计[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/leaveHosCount")
    @SysLogger("leaveHosCount")
    public RespDTO<Map<String, Object>> leaveHosCount(@RequestBody FilterVO filterVO) {
        return RespDTO.onSuc(consoleFacade.leaveHosCount(filterVO));
    }

    /**
     * 质控病历统计
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "质控病历统计[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/mrCount")
    @SysLogger("mrCount")
    public RespDTO<Map<String, Object>> mrCount(@RequestBody FilterVO filterVO) {
        return RespDTO.onSuc(consoleFacade.mrCount(filterVO));
    }

    /**
     * 各模块缺陷占比排行
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "各模块缺陷占比排行[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/entryCountGroupByCase")
    @SysLogger("entryCountGroupByCase")
    public RespDTO<Map<String, Object>> entryCountGroupByCase(@RequestBody FilterVO filterVO) {
        return RespDTO.onSuc(consoleFacade.entryCountGroupByCase(filterVO));
    }

    /**
     * 条目缺陷占比
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "条目缺陷占比[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/entryCountGroupByEntry")
    @SysLogger("entryCountGroupByEntry")
    public RespDTO<Map<String, Object>> entryCountGroupByEntry(@RequestBody FilterVO filterVO) {
        return RespDTO.onSuc(consoleFacade.entryCountGroupByEntry(filterVO));
    }

    /**
     * 各科室缺陷占比
     *
     * @param filterVO
     * @return
     */
    @ApiOperation(value = "各科室缺陷占比[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/entryByDept")
    @SysLogger("entryByDept")
    public RespDTO<Map<String, Object>> entryByDept(@RequestBody FilterVO filterVO) {
        return RespDTO.onSuc(consoleFacade.entryByDept(filterVO));
    }
    //endregion-----------------------单独接口结束-------------------------------

    //region-----------------------分页接口开始-------------------------------

    /**
     * 各模块缺陷占比（分页）
     *
     * @param filterPageVO
     * @return
     */
    @ApiOperation(value = "各模块缺陷占比（分页）[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/entryCountGroupByCasePage")
    @SysLogger("entryCountGroupByCasePage")
    public RespDTO<IPage<NumDTO>> entryCountGroupByCasePage(@RequestBody FilterPageVO filterPageVO) {
        return RespDTO.onSuc(consoleFacade.entryCountGroupByCasePage(filterPageVO));
    }

    /**
     * 各模块缺陷占比（分页）
     *
     * @param filterPageVO
     * @return
     */
    @ApiOperation(value = "条目缺陷占比（分页）[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/entryCountGroupByEntryPage")
    @SysLogger("entryCountGroupByEntryPage")
    public RespDTO<IPage<NumDTO>> entryCountGroupByEntryPage(@RequestBody FilterPageVO filterPageVO) {
        return RespDTO.onSuc(consoleFacade.entryCountGroupByEntryPage(filterPageVO));
    }

    /**
     * 按科室统计平均住院天数（分页）
     *
     * @param filterPageVO
     * @return
     */
    @ApiOperation(value = "按科室统计平均住院天数（分页）[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年<br>" +
                    "dateType： 时间类型 1-本月/本年，2-上月/去年，3-去年本月/去年<br>")
    @PostMapping("/getAverageDayNumPage")
    @SysLogger("getAverageDayNumPage")
    public RespDTO<IPage<AverageStatisticsDTO>> getAverageDayNumPage(@RequestBody FilterPageVO filterPageVO) {
        return RespDTO.onSuc(consoleFacade.getAverageDayNumPage(filterPageVO));
    }

    /**
     * 按科室统计平均住院费用（分页）
     *
     * @param filterPageVO
     * @return
     */
    @ApiOperation(value = "按科室统计平均住院费用（分页）[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年<br>" +
                    "dateType： 时间类型 1-本月/本年，2-上月/去年，3-去年本月/去年<br>")
    @PostMapping("/getAverageFeePage")
    @SysLogger("getAverageFeePage")
    public RespDTO<IPage<AverageStatisticsDTO>> getAverageFeePage(@RequestBody FilterPageVO filterPageVO) {
        return RespDTO.onSuc(consoleFacade.getAverageFeePage(filterPageVO));
    }

    /**
     * 各科室质控平均分（分页）
     *
     * @param filterPageVO
     * @return
     */
    @ApiOperation(value = "各科室质控平均分（分页）[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/getAverageScoreByDeptPage")
    @SysLogger("getAverageScoreByDeptPage")
    public RespDTO<IPage<AverageStatisticsDTO>> getAverageScoreByDeptPage(@RequestBody FilterPageVO filterPageVO) {
        return RespDTO.onSuc(consoleFacade.getAverageScoreByDeptPage(filterPageVO));
    }

    /**
     * 各科室缺陷占比排行（分页）
     *
     * @param filterPageVO
     * @return
     */
    @ApiOperation(value = "各科室缺陷占比排行（分页）[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/resultStatisticsByDeptPage")
    @SysLogger("resultStatisticsByDeptPage")
    public RespDTO<IPage<NumDTO>> resultStatisticsByDeptPage(@RequestBody FilterPageVO filterPageVO) {
        return RespDTO.onSuc(consoleFacade.resultStatisticsByDeptPage(filterPageVO));
    }

    /**
     * 各科室甲级病历占比排行（分页）
     *
     * @param filterPageVO
     * @return
     */
    @ApiOperation(value = "各科室甲级病历占比排行（分页）[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>")
    @PostMapping("/levelPercentGroupByDeptPage")
    @SysLogger("levelPercentGroupByDeptPage")
    public RespDTO<IPage<NumDTO>> levelPercentGroupByDeptPage(@RequestBody FilterPageVO filterPageVO) {
        return RespDTO.onSuc(consoleFacade.levelPercentGroupByDeptPage(filterPageVO));
    }

    //endregion-----------------------分页接口结束-------------------------------

    /**
     * 各科室缺陷占比（组合）
     *
     * @param filterOrderVO
     * @return
     */
    @ApiOperation(value = "各科室缺陷占比（组合）[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>" +
                    "level： 病历等级 <br>" +
                    "name： 科室名称 <br>" +
                    "asc： 排序（升序） <br>" +
                    "desc： 排序（降序） <br>")
    @PostMapping("/levelStatistics")
    @SysLogger("levelStatistics")
    public RespDTO<List<LevelStatisticsDTO>> levelStatistics(@RequestBody FilterOrderVO filterOrderVO) {
        return RespDTO.onSuc(consoleFacade.levelStatistics(filterOrderVO));
    }

    /**
     * 病案首页合格率占比
     *
     * @param filterOrderVO
     * @return
     */
    @ApiOperation(value = "病案首页合格率占比[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>" +
                    "level： 病历等级 <br>" +
                    "name： 科室名称 <br>" +
                    "asc： 排序（升序） <br>" +
                    "desc： 排序（降序） <br>")
    @PostMapping("/homePageLevelStatistics")
    @SysLogger("homePageLevelStatistics")
    public RespDTO<List<LevelStatisticsDTO>> homePageLevelStatistics(@RequestBody FilterOrderVO filterOrderVO) {
        return RespDTO.onSuc(consoleFacade.homePageLevelStatistics(filterOrderVO));
    }

    /**
     * 病案首页合格率占比（首页）
     *
     * @param filterOrderVO
     * @return
     */
    @ApiOperation(value = "病案首页合格率占比（首页）[by:zhaops]",
            notes = "type： 统计维度 1-本月，2-本年(必填)<br>" +
                    "level： 病历等级 <br>" +
                    "name： 科室名称 <br>" +
                    "asc： 排序（升序） <br>" +
                    "desc： 排序（降序） <br>")
    @PostMapping("/homePageLevelLimit")
    @SysLogger("homePageLevelLimit")
    public RespDTO<List<LevelStatisticsDTO>> homePageLevelLimit(@RequestBody FilterOrderVO filterOrderVO) {
        return RespDTO.onSuc(consoleFacade.homePageLevelLimit(filterOrderVO));
    }
}